netapp_ontap.models.data_sources_aggregations_inner API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.data_sources_aggregations_inner`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class DataSourcesAggregationsInnerSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the DataSourcesAggregationsInner object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `entity_count: Size GET POST PATCH`

    Number of entities in the data_source.

    Example: 20

  `name: str GET POST PATCH`

    Name of the data_source.

    Example: data_source_1

  `sensitive_entity_count: Size GET POST PATCH`

    Number of sensitive entities in the data_source.

    Example: 100

  `sensitive_entity_percent: Size GET POST PATCH`

    Percentage of sensitive entities in the data_source.

    Example: 23

  `space_used: Size GET POST PATCH`

    Total utilized size of the data_source.

    Example: 2066541

  `top_document_categories: str GET POST PATCH`

    Top document categories of the data_source.

    Example: General Privacy, Financial Documents

  `uuid: str GET POST PATCH`

    UUID of the data_source.

    Example: 4ea7a442-86d1-11e0-ae1c-123478563412